Crate bronto
bronto
0.1.0
All Items
Crate Items
Macros
Crate
bronto
Macros

array
Initializes a constant array. The sequence of arguments passed until the first semicolon initializes the first values in the array. The remaining arguments are initialzed with the value provided to the named
fill
parameter.